@@ -340,7 +340,7 @@ def run_tool_shapes_grid_4(GRID=None, POINTS=None, FREQ=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Contour_Lines_from_Grid(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYSTEM=None, VERTEX=None, LINE_OMP=None, LINE_PARTS=None, POLY_OMP=None, POLY_PARTS=None, SCALE=None, BOUNDARY=None, MINLENGTH=None, INTERVALS=None, ZMIN=None, ZMAX=None, ZSTEP=None, ZLIST=None, Verbose=2):
+def Contour_Lines_from_Grid(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYSTEM=None, VERTEX=None, LINE_OMP=None, LINE_PARTS=None, POLY_OMP=None, POLY_PARTS=None, PRECISION=None, SCALE=None, BOUNDARY=None, MINLENGTH=None, INTERVALS=None, ZMIN=None, ZMAX=None, ZSTEP=None, ZLIST=None, Verbose=2):
     '''
     Contour Lines from Grid
     ----------
@@ -357,6 +357,7 @@ def Contour_Lines_from_Grid(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYS
     - LINE_PARTS [`boolean`] : Split Line Parts. Default: 1
     - POLY_OMP [`boolean`] : Parallel Processing. Default: 1
     - POLY_PARTS [`boolean`] : Split Polygon Parts. Default: 1
+    - PRECISION [`boolean`] : Coordinate Precision Fix. Default: 0 Check to avoid coordinate precision issues with polygon construction, particularly helpful with geographic coordinates or in general with comparatively small cell sizes.
     - SCALE [`floating point number`] : Interpolation Scale. Minimum: 0.000000 Default: 1.000000 set greater one for line smoothing
     - BOUNDARY [`boolean`] : Boundary Extension. Default: 0 Extend contours beyond boundary. Internally input grid is extrapolated by one cell size in each direction (top, down, left, right).
     - MINLENGTH [`floating point number`] : Minimum Length. Minimum: 0.000000 Default: 0.000000 Contour line segments with minimum length [map units] or less will be removed from resulting data set.
@@ -382,6 +383,7 @@ def Contour_Lines_from_Grid(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYS
         Tool.Set_Option('LINE_PARTS', LINE_PARTS)
         Tool.Set_Option('POLY_OMP', POLY_OMP)
         Tool.Set_Option('POLY_PARTS', POLY_PARTS)
+        Tool.Set_Option('PRECISION', PRECISION)
         Tool.Set_Option('SCALE', SCALE)
         Tool.Set_Option('BOUNDARY', BOUNDARY)
         Tool.Set_Option('MINLENGTH', MINLENGTH)
@@ -393,7 +395,7 @@ def Contour_Lines_from_Grid(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYS
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_5(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYSTEM=None, VERTEX=None, LINE_OMP=None, LINE_PARTS=None, POLY_OMP=None, POLY_PARTS=None, SCALE=None, BOUNDARY=None, MINLENGTH=None, INTERVALS=None, ZMIN=None, ZMAX=None, ZSTEP=None, ZLIST=None, Verbose=2):
+def run_tool_shapes_grid_5(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYSTEM=None, VERTEX=None, LINE_OMP=None, LINE_PARTS=None, POLY_OMP=None, POLY_PARTS=None, PRECISION=None, SCALE=None, BOUNDARY=None, MINLENGTH=None, INTERVALS=None, ZMIN=None, ZMAX=None, ZSTEP=None, ZLIST=None, Verbose=2):
     '''
     Contour Lines from Grid
     ----------
@@ -410,6 +412,7 @@ def run_tool_shapes_grid_5(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYST
     - LINE_PARTS [`boolean`] : Split Line Parts. Default: 1
     - POLY_OMP [`boolean`] : Parallel Processing. Default: 1
     - POLY_PARTS [`boolean`] : Split Polygon Parts. Default: 1
+    - PRECISION [`boolean`] : Coordinate Precision Fix. Default: 0 Check to avoid coordinate precision issues with polygon construction, particularly helpful with geographic coordinates or in general with comparatively small cell sizes.
     - SCALE [`floating point number`] : Interpolation Scale. Minimum: 0.000000 Default: 1.000000 set greater one for line smoothing
     - BOUNDARY [`boolean`] : Boundary Extension. Default: 0 Extend contours beyond boundary. Internally input grid is extrapolated by one cell size in each direction (top, down, left, right).
     - MINLENGTH [`floating point number`] : Minimum Length. Minimum: 0.000000 Default: 0.000000 Contour line segments with minimum length [map units] or less will be removed from resulting data set.
@@ -435,6 +438,7 @@ def run_tool_shapes_grid_5(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYST
         Tool.Set_Option('LINE_PARTS', LINE_PARTS)
         Tool.Set_Option('POLY_OMP', POLY_OMP)
         Tool.Set_Option('POLY_PARTS', POLY_PARTS)
+        Tool.Set_Option('PRECISION', PRECISION)
         Tool.Set_Option('SCALE', SCALE)
         Tool.Set_Option('BOUNDARY', BOUNDARY)
         Tool.Set_Option('MINLENGTH', MINLENGTH)
@@ -1166,6 +1170,104 @@ def run_tool_shapes_grid_19(GRID=None, POLYGONS=None, BOUNDARY_CELLS=None, BOUND
         return Tool.Execute(Verbose)
     return False
 
+def Line_Direction(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+    '''
+    Line Direction
+    ----------
+    [shapes_grid.20]\n
+    Creates a grid of the direction (fat) of a line shapes.\n
+    Arguments
+    ----------
+    - INPUT [`input shapes`] : Shapes
+    - TARGET_TEMPLATE [`optional input grid`] : Target System. use this grid's system for output grids
+    - GRID [`output grid`] : Grid
+    - ORDER_FIELD [`table field`] : Order Field. Field for order in which the shape will be sorted prior to rasterization.
+    - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
+    - TARGET_USER_SIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
+    - TARGET_USER_XMIN [`floating point number`] : West. Default: 0.000000
+    - TARGET_USER_XMAX [`floating point number`] : East. Default: 100.000000
+    - TARGET_USER_YMIN [`floating point number`] : South. Default: 0.000000
+    - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
+    - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
+    - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
+    - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
+    - TARGET_SYSTEM [`grid system`] : Grid System
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('shapes_grid', '20', 'Line Direction')
+    if Tool.is_Okay():
+        Tool.Set_Input ('INPUT', INPUT)
+        Tool.Set_Input ('TARGET_TEMPLATE', TARGET_TEMPLATE)
+        Tool.Set_Output('GRID', GRID)
+        Tool.Set_Option('ORDER_FIELD', ORDER_FIELD)
+        Tool.Set_Option('TARGET_DEFINITION', TARGET_DEFINITION)
+        Tool.Set_Option('TARGET_USER_SIZE', TARGET_USER_SIZE)
+        Tool.Set_Option('TARGET_USER_XMIN', TARGET_USER_XMIN)
+        Tool.Set_Option('TARGET_USER_XMAX', TARGET_USER_XMAX)
+        Tool.Set_Option('TARGET_USER_YMIN', TARGET_USER_YMIN)
+        Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
+        Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
+        Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
+        Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
+        Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
+        return Tool.Execute(Verbose)
+    return False
+
+def run_tool_shapes_grid_20(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+    '''
+    Line Direction
+    ----------
+    [shapes_grid.20]\n
+    Creates a grid of the direction (fat) of a line shapes.\n
+    Arguments
+    ----------
+    - INPUT [`input shapes`] : Shapes
+    - TARGET_TEMPLATE [`optional input grid`] : Target System. use this grid's system for output grids
+    - GRID [`output grid`] : Grid
+    - ORDER_FIELD [`table field`] : Order Field. Field for order in which the shape will be sorted prior to rasterization.
+    - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
+    - TARGET_USER_SIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
+    - TARGET_USER_XMIN [`floating point number`] : West. Default: 0.000000
+    - TARGET_USER_XMAX [`floating point number`] : East. Default: 100.000000
+    - TARGET_USER_YMIN [`floating point number`] : South. Default: 0.000000
+    - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
+    - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
+    - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
+    - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
+    - TARGET_SYSTEM [`grid system`] : Grid System
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('shapes_grid', '20', 'Line Direction')
+    if Tool.is_Okay():
+        Tool.Set_Input ('INPUT', INPUT)
+        Tool.Set_Input ('TARGET_TEMPLATE', TARGET_TEMPLATE)
+        Tool.Set_Output('GRID', GRID)
+        Tool.Set_Option('ORDER_FIELD', ORDER_FIELD)
+        Tool.Set_Option('TARGET_DEFINITION', TARGET_DEFINITION)
+        Tool.Set_Option('TARGET_USER_SIZE', TARGET_USER_SIZE)
+        Tool.Set_Option('TARGET_USER_XMIN', TARGET_USER_XMIN)
+        Tool.Set_Option('TARGET_USER_XMAX', TARGET_USER_XMAX)
+        Tool.Set_Option('TARGET_USER_YMIN', TARGET_USER_YMIN)
+        Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
+        Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
+        Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
+        Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
+        Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
+        return Tool.Execute(Verbose)
+    return False
+
 def Grid_Values_and_Polygon_Attributes_to_Points(GRID=None, POLYGONS=None, POINTS=None, GRID_GRIDSYSTEM=None, ATTRIBUTE=None, Verbose=2):
     '''
     Grid Values and Polygon Attributes to Points
