@@ -28,7 +28,7 @@ def Analytical_Hillshading(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
     - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
     - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
     - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
-    - DATE [`date`] : Day. Default: 2024-06-06
+    - DATE [`date`] : Day. Default: 2024-09-24
     - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
     - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
@@ -73,7 +73,7 @@ def run_tool_ta_lighting_0(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
     - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
     - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
     - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
-    - DATE [`date`] : Day. Default: 2024-06-06
+    - DATE [`date`] : Day. Default: 2024-09-24
     - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
     - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
@@ -134,8 +134,8 @@ def Potential_Incoming_Solar_Radiation(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=No
     - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
     - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
     - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1
-    - DAY [`date`] : Day. Default: 2024-06-06
-    - DAY_STOP [`date`] : Last Day. Default: 2024-06-06
+    - DAY [`date`] : Day. Default: 2024-09-24
+    - DAY_STOP [`date`] : Last Day. Default: 2024-09-24
     - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
     - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
@@ -220,8 +220,8 @@ def run_tool_ta_lighting_2(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=None, GRD_LINK
     - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
     - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
     - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1
-    - DAY [`date`] : Day. Default: 2024-06-06
-    - DAY_STOP [`date`] : Last Day. Default: 2024-06-06
+    - DAY [`date`] : Day. Default: 2024-09-24
+    - DAY_STOP [`date`] : Last Day. Default: 2024-09-24
     - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
     - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
@@ -583,7 +583,7 @@ def Geomorphons(DEM=None, GEOMORPHONS=None, THRESHOLD=None, RADIUS=None, METHOD=
     - DEM [`input grid`] : Elevation
     - GEOMORPHONS [`output grid`] : Geomorphons
     - THRESHOLD [`floating point number`] : Threshold Angle. Minimum: 0.000000 Default: 1.000000 Flatness threshold angle (degrees).
-    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000
+    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000 The radial limit (search radius) [map units].
     - METHOD [`choice`] : Method. Available Choices: [0] multi scale [1] line tracing Default: 1
     - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000
 
@@ -614,7 +614,7 @@ def run_tool_ta_lighting_8(DEM=None, GEOMORPHONS=None, THRESHOLD=None, RADIUS=No
     - DEM [`input grid`] : Elevation
     - GEOMORPHONS [`output grid`] : Geomorphons
     - THRESHOLD [`floating point number`] : Threshold Angle. Minimum: 0.000000 Default: 1.000000 Flatness threshold angle (degrees).
-    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000
+    - RADIUS [`floating point number`] : Radial Limit. Minimum: 0.000000 Default: 10000.000000 The radial limit (search radius) [map units].
     - METHOD [`choice`] : Method. Available Choices: [0] multi scale [1] line tracing Default: 1
     - DLEVEL [`floating point number`] : Multi Scale Factor. Minimum: 1.250000 Default: 3.000000
 
