@@ -776,62 +776,43 @@ private:
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef enum
+enum class ESG_CRS_Format
 {
-	SG_PROJ_FMT_WKT,
-	SG_PROJ_FMT_Proj4,
-	SG_PROJ_FMT_EPSG,
-	SG_PROJ_FMT_Undefined
-}
-TSG_Projection_Format;
+	WKT1, WKT2, PROJ, JSON, ESRI, CODE, Undefined, WKT = WKT1
+};
 
 //---------------------------------------------------------
-typedef enum
+enum class ESG_CRS_Type
 {
-	SG_PROJ_TYPE_CS_Projected,
-	SG_PROJ_TYPE_CS_Geographic,
-	SG_PROJ_TYPE_CS_Geocentric,
-	SG_PROJ_TYPE_CS_Undefined
-}
-TSG_Projection_Type;
+	Geographic, Geodetic, Geocentric, Projection, Undefined
+};
 
 //---------------------------------------------------------
-typedef enum
+enum class ESG_Projection_Unit
 {
-	SG_PROJ_UNIT_Kilometer,
-	SG_PROJ_UNIT_Meter,
-	SG_PROJ_UNIT_Decimeter,
-	SG_PROJ_UNIT_Centimeter,
-	SG_PROJ_UNIT_Millimeter,
-	SG_PROJ_UNIT_Int_Nautical_Mile,
-	SG_PROJ_UNIT_Int_Inch,
-	SG_PROJ_UNIT_Int_Foot,
-	SG_PROJ_UNIT_Int_Yard,
-	SG_PROJ_UNIT_Int_Statute_Mile,
-	SG_PROJ_UNIT_Int_Fathom,
-	SG_PROJ_UNIT_Int_Chain,
-	SG_PROJ_UNIT_Int_Link,
-	SG_PROJ_UNIT_US_Inch,
-	SG_PROJ_UNIT_US_Foot,
-	SG_PROJ_UNIT_US_Yard,
-	SG_PROJ_UNIT_US_Chain,
-	SG_PROJ_UNIT_US_Statute_Mile,
-	SG_PROJ_UNIT_Indian_Yard,
-	SG_PROJ_UNIT_Indian_Foot,
-	SG_PROJ_UNIT_Indian_Chain,
-	SG_PROJ_UNIT_Undefined
-}
-TSG_Projection_Unit;
-
-//---------------------------------------------------------
-SAGA_API_DLL_EXPORT TSG_Projection_Type	SG_Get_Projection_Type				(const CSG_String &Identifier);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Type_Identifier	(TSG_Projection_Type Type);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Type_Name			(TSG_Projection_Type Type);
-
-SAGA_API_DLL_EXPORT TSG_Projection_Unit	SG_Get_Projection_Unit				(const CSG_String &Identifier);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Unit_Identifier	(TSG_Projection_Unit Unit);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Unit_Name			(TSG_Projection_Unit Unit, bool bSimple = false);
-SAGA_API_DLL_EXPORT double				SG_Get_Projection_Unit_To_Meter		(TSG_Projection_Unit Unit);
+	Kilometer,
+	Meter,
+	Decimeter,
+	Centimeter,
+	Millimeter,
+	Int_Nautical_Mile,
+	Int_Inch,
+	Int_Foot,
+	Int_Yard,
+	Int_Statute_Mile,
+	Int_Fathom,
+	Int_Chain,
+	Int_Link,
+	US_Inch,
+	US_Foot,
+	US_Yard,
+	US_Chain,
+	US_Statute_Mile,
+	Indian_Yard,
+	Indian_Foot,
+	Indian_Chain,
+	Undefined, First = Kilometer
+};
 
 
 ///////////////////////////////////////////////////////////
@@ -851,76 +832,90 @@ public:
 
 									CSG_Projection			(const CSG_Projection &Projection);
 	bool							Create					(const CSG_Projection &Projection);
-	bool							Assign					(const CSG_Projection &Projection);
-	CSG_Projection &				operator =				(const CSG_Projection &Projection)	{	Assign(Projection);	return( *this );	}
+	CSG_Projection &				operator =				(const CSG_Projection &Projection) { Create(Projection); return( *this ); }
 
-									CSG_Projection			(int Authority_ID, const SG_Char *Authority = NULL);
-	bool							Create					(int Authority_ID, const SG_Char *Authority = NULL);
-	bool							Assign					(int Authority_ID, const SG_Char *Authority = NULL);
-	CSG_Projection &				operator =				(int Authority_ID)					{	Assign(Authority_ID);	return( *this );	}
+									CSG_Projection			(const char       *Definition);
+	bool							Create					(const char       *Definition);
+	CSG_Projection &				operator =				(const char       *Definition)     { Create(Definition); return( *this ); }
 
-									CSG_Projection			(const CSG_String &Projection, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Create					(const CSG_String &Projection, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Assign					(const CSG_String &Projection, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	CSG_Projection &				operator =				(const CSG_String &Projection)		{	Assign(Projection);	return( *this );	}
+									CSG_Projection			(const wchar_t    *Definition);
+	bool							Create					(const wchar_t    *Definition);
+	CSG_Projection &				operator =				(const wchar_t    *Definition)     { Create(Definition); return( *this ); }
 
-									CSG_Projection			(const CSG_String &WKT, const CSG_String &Proj4);
-	bool							Create					(const CSG_String &WKT, const CSG_String &Proj4);
-	bool							Assign					(const CSG_String &WKT, const CSG_String &Proj4);
+									CSG_Projection			(const CSG_String &Definition);
+	bool							Create					(const CSG_String &Definition);
+	CSG_Projection &				operator =				(const CSG_String &Definition)     { Create(Definition); return( *this ); }
 
-	bool							is_Okay					(void)	const	{	return( m_Type != SG_PROJ_TYPE_CS_Undefined );	}
-	bool							is_Equal				(const CSG_Projection &Projection)	const;
-	bool							operator ==				(const CSG_Projection &Projection)	const	{	return( is_Equal(Projection) == true  );	}
-	bool							operator !=				(const CSG_Projection &Projection)	const	{	return( is_Equal(Projection) == false );	}
+									CSG_Projection			(int Code, const SG_Char *Authority = NULL);
+	bool							Create					(int Code, const SG_Char *Authority = NULL);
+	CSG_Projection &				operator =				(int Code)                         { Create(Code      ); return( *this ); }
 
+	bool							Assign					(const CSG_Projection &Projection)          { return( Create(Projection      ) ); }
+	bool							Assign					(const CSG_String &Definition)              { return( Create(Definition      ) ); }
+	bool							Assign					(int Code, const SG_Char *Authority = NULL) { return( Create(Code, Authority ) ); }
+
+	bool							is_Okay					(void)	const	{	return( m_Type != ESG_CRS_Type::Undefined );	}
+	bool							is_Equal				(const CSG_Projection &Projection) const;
+	bool							operator ==				(const CSG_Projection &Projection) const { return( is_Equal(Projection) == true  ); }
+	bool							operator !=				(const CSG_Projection &Projection) const { return( is_Equal(Projection) == false ); }
+
+	static const CSG_Projection &	Get_GCS_WGS84			(void);
 	bool							Set_GCS_WGS84			(void);
+
+	static CSG_Projection			Get_UTM_WGS84			(int Zone, bool bSouth = false);
 	bool							Set_UTM_WGS84			(int Zone, bool bSouth = false);
 
-	bool							Load					(const CSG_String &FileName, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Save					(const CSG_String &FileName, TSG_Projection_Format Format = SG_PROJ_FMT_WKT)	const;
+	bool							Load					(const CSG_String &File);
+	bool							Save					(const CSG_String &File, ESG_CRS_Format Format = ESG_CRS_Format::WKT) const;
 
-	bool							Load					(CSG_File &Stream, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Save					(CSG_File &Stream, TSG_Projection_Format Format = SG_PROJ_FMT_WKT)	const;
+	bool							Load					(CSG_File &Stream);
+	bool							Save					(CSG_File &Stream      , ESG_CRS_Format Format = ESG_CRS_Format::WKT) const;
 
 	bool							Load					(const CSG_MetaData &Projection);
-	bool							Save					(      CSG_MetaData &Projection)	const;
+	bool							Save					(      CSG_MetaData &Projection) const;
 
-	const CSG_String &				Get_Name				(void)	const	{	return( m_Name          );	}
-	const CSG_String &				Get_WKT					(void)	const	{	return( m_WKT           );	}
-	const CSG_String &				Get_Proj4				(void)	const	{	return( m_Proj4         );	}
-	const CSG_String &				Get_Authority			(void)	const	{	return( m_Authority     );	}
-	int								Get_Authority_ID		(void)	const	{	return( m_Authority_ID  );	}
-	int								Get_EPSG				(void)	const	{	return( m_Authority.Cmp("EPSG") ? -1 : m_Authority_ID );	}
+	CSG_String						Get_Description			(bool bDetails = false)	const;
 
-	CSG_String						Get_Description			(void)	const;
+	const CSG_String &				Get_Name				(void)	const	{	return( m_Name      );	}
 
-	TSG_Projection_Type				Get_Type				(void)	const	{	return( m_Type  );	}
-	CSG_String						Get_Type_Identifier		(void)	const	{	return( SG_Get_Projection_Type_Identifier(m_Type) );	}
-	CSG_String						Get_Type_Name			(void)	const	{	return( SG_Get_Projection_Type_Name      (m_Type) );	}
+	const CSG_String &				Get_WKT					(void)	const	{	return( m_WKT2      );	}
+	      CSG_String				Get_WKT1				(void)	const;
+	const CSG_String &				Get_WKT2				(void)	const	{	return( m_WKT2      );	}
+	const CSG_String &				Get_PROJ				(void)	const	{	return( m_PROJ      );	}
+	      CSG_String				Get_JSON				(void)	const;
+	      CSG_String				Get_ESRI				(void)	const;
+	      CSG_String				Get_XML					(void)	const;
+	const CSG_String &				Get_Authority			(void)	const	{	return( m_Authority );	}
+	int								Get_Code				(void)	const	{	return( m_Code      );	}
 
-	bool							is_Projection			(void)	const	{	return( m_Type == SG_PROJ_TYPE_CS_Projected  );	}
-	bool							is_Geographic			(void)	const	{	return( m_Type == SG_PROJ_TYPE_CS_Geographic );	}
-	bool							is_Geocentric			(void)	const	{	return( m_Type == SG_PROJ_TYPE_CS_Geocentric );	}
+	const CSG_String &				Get_Proj4				(void)	const	{	return( m_PROJ      );	}
+	int								Get_Authority_ID		(void)	const	{	return( m_Code      );	}
+	int								Get_EPSG				(void)	const	{	return( m_Authority.CmpNoCase("EPSG") ? -1 : m_Code );	}
 
+	bool							is_Geographic			(void)	const	{	return( m_Type == ESG_CRS_Type::Geographic );	}
+	bool							is_Geodetic				(void)	const	{	return( m_Type == ESG_CRS_Type::Geodetic   );	}
+	bool							is_Geocentric			(void)	const	{	return( m_Type == ESG_CRS_Type::Geocentric );	}
+	bool							is_Projection			(void)	const	{	return( m_Type == ESG_CRS_Type::Projection );	}
 
-	TSG_Projection_Unit				Get_Unit				(void)	const	{	return( m_Unit  );	}
-	CSG_String						Get_Unit_Identifier		(void)	const	{	return( SG_Get_Projection_Unit_Identifier(m_Unit) );	}
-	CSG_String						Get_Unit_Name			(void)	const	{	return( m_Unit_Name     );	}
-	double							Get_Unit_To_Meter		(void)	const	{	return( m_Unit_To_Meter );	}
+	ESG_CRS_Type					Get_Type				(void)	const	{	return( m_Type );	}
+	CSG_String						Get_Type_Identifier		(void)	const;
+	CSG_String						Get_Type_Name			(void)	const;
+
+	ESG_Projection_Unit				Get_Unit				(void)	const	{	return( m_Unit );	}
+	CSG_String						Get_Unit_Identifier		(void)	const;
+	CSG_String						Get_Unit_Name			(void)	const;
+	double							Get_Unit_To_Meter		(void)	const;
 
 
 private:
 
-	int								m_Authority_ID;
+	int								m_Code;
 
-	double							m_Unit_To_Meter;
+	ESG_CRS_Type					m_Type;
 
-	TSG_Projection_Type				m_Type;
-
-	TSG_Projection_Unit				m_Unit;
-
-	CSG_String						m_Name, m_WKT, m_Proj4, m_Authority, m_Unit_Name;
+	ESG_Projection_Unit				m_Unit;
 
+	CSG_String						m_Name, m_Authority, m_PROJ, m_WKT2;
 
 };
 
@@ -942,58 +937,71 @@ public:
 	CSG_Projections(void);
 	virtual ~CSG_Projections(void);
 
-									CSG_Projections			(bool bLoad_DB);
-	bool							Create					(bool bLoad_DB = true);
-
-									CSG_Projections			(const CSG_String &File_DB);
-	bool							Create					(const CSG_String &File_DB);
+									CSG_Projections			(bool LoadCodeList);
+	bool							Create					(bool LoadCodeList = true);
 
 	void							Destroy					(void);
 
-	bool							Reset_Dictionary		(void);
-	bool							Load_Dictionary			(const CSG_String &FileName);
-	bool							Save_Dictionary			(const CSG_String &FileName);
+	static bool						Parse					(const CSG_String &Definition, CSG_String *WKT1 = NULL, CSG_String *WKT2 = NULL, CSG_String *PROJ = NULL, CSG_String *ESRI = NULL);
+	static CSG_String				Parse					(const CSG_String &Definition, ESG_CRS_Format Format);
 
-	bool							Load_DB					(const CSG_String &FileName, bool bAppend = false);
-	bool							Save_DB					(const CSG_String &FileName);
-
-	sLong							Get_Count				(void)	const;
+	bool							Load					(const CSG_String &File, bool bAppend = false);
+	bool							Save					(const CSG_String &File);
 
 	bool							Add						(const CSG_Projection &Projection);
 	bool							Add						(const SG_Char *WKT, const SG_Char *Proj4, const SG_Char *Authority, int Authority_ID);
 
-	CSG_Projection					Get_Projection			(sLong Index)	const;
+	sLong							Get_Count				(void)	const;
+
 	CSG_Projection					operator []				(sLong Index)	const	{	return( Get_Projection(Index) );	}
+	CSG_Projection					Get_Projection			(sLong Index)	const;
+	const SG_Char *					Get_Projection			(                            int Code, const SG_Char    *Authority = NULL) const;
+	bool							Get_Projection			(CSG_Projection &Projection, int Code, const SG_Char    *Authority = NULL) const;
 
-	bool							Get_Projection			(CSG_Projection &Projection,                              int EPSG_ID     )	const;
-	bool							Get_Projection			(CSG_Projection &Projection, const CSG_String &Authority, int Authority_ID)	const;
+	bool							Get_Preference			(CSG_Projection &Projection, int Code, const CSG_String &Authority       ) const;
+	bool							Get_Preference			(CSG_Projection &Projection          , const CSG_String &Authority_Code  ) const;
 
-	CSG_String						Get_Names_List			(TSG_Projection_Type Type = SG_PROJ_TYPE_CS_Undefined)	const;
+	CSG_String						Get_Names_List			(ESG_CRS_Type Type = ESG_CRS_Type::Undefined, bool bAddSelect = true)      const;
 
-	static CSG_MetaData				WKT_to_MetaData			(const CSG_String &WKT);
+	static ESG_CRS_Type				Get_CRS_Type			(const CSG_String &Identifier);
+	static CSG_String				Get_CRS_Type_Identifier	(ESG_CRS_Type Type);
+	static CSG_String				Get_CRS_Type_Name		(ESG_CRS_Type Type);
 
-	bool							WKT_to_Proj4			(CSG_String &Proj4, const CSG_String &WKT  )	const;
-	bool							WKT_from_Proj4			(CSG_String &WKT  , const CSG_String &Proj4)	const;
+	static ESG_Projection_Unit		Get_Unit				(const CSG_String &Identifier);
+	static const CSG_String			Get_Unit_Identifier		(ESG_Projection_Unit Unit);
+	static const CSG_String			Get_Unit_Name			(ESG_Projection_Unit Unit, bool bSimple = true);
+	static double					Get_Unit_To_Meter		(ESG_Projection_Unit Unit);
 
-	bool							EPSG_to_Proj4			(CSG_String &Proj4, int EPSG_Code)				const;
-	bool							EPSG_to_WKT				(CSG_String &WKT  , int EPSG_Code)				const;
-
-	static const CSG_Projection &	Get_GCS_WGS84			(void);
-	static CSG_Projection			Get_UTM_WGS84			(int Zone, bool bSouth = false);
+	static CSG_String				Convert_WKT2_to_XML		(const CSG_String &WKT);
 
 
 private:
 
-	CSG_Translator					m_WKT_to_Proj4, m_Proj4_to_WKT, m_EPSG_to_Idx;
-
-	class CSG_Table					*m_pProjections;
+	class CSG_Table					*m_pProjections, *m_pPreferences;
 
 
 	void							_On_Construction			(void);
 
-	static bool						_WKT_to_MetaData			(CSG_MetaData &MetaData, const CSG_String &WKT);
 
-	bool							_WKT_to_Proj4_Set_Datum		(CSG_String &Proj4, const CSG_MetaData &WKT)	const;
+private:
+
+	CSG_Translator					m_WKT1_to_Proj4, m_Proj4_to_WKT1, m_EPSG_to_Idx;
+
+	bool							_Load						(class CSG_Table *pTable, const CSG_String &File, bool bAppend = false) const;
+
+	static CSG_Projection			_Get_Projection				(class CSG_Table_Record *pProjection);
+
+	bool							_Add_Preferences			(void);
+
+	static CSG_MetaData				_WKT2_to_MetaData			(const CSG_String &WKT, bool bTrim);
+	static bool						_WKT2_to_MetaData			(CSG_MetaData &MetaData, const CSG_String &WKT);
+
+	static CSG_MetaData				_WKT1_to_MetaData			(const CSG_String &WKT);
+	static bool						_WKT1_to_MetaData			(CSG_MetaData &MetaData, const CSG_String &WKT);
+
+	bool							_WKT1_to_Proj4				(CSG_String &Proj4, const CSG_String &WKT  )	const;
+	bool							_WKT1_from_Proj4			(CSG_String &WKT  , const CSG_String &Proj4)	const;
+	bool							_WKT1_to_Proj4_Set_Datum	(CSG_String &Proj4, const CSG_MetaData &WKT)	const;
 
 	static bool						_Proj4_Find_Parameter		(                   const CSG_String &Proj4, const CSG_String &Key);
 	static bool						_Proj4_Read_Parameter		(CSG_String &Value, const CSG_String &Proj4, const CSG_String &Key);
@@ -1002,22 +1010,22 @@ private:
 	static bool						_Proj4_Get_Prime_Meridian	(CSG_String &Value, const CSG_String &Proj4);
 	static bool						_Proj4_Get_Unit				(CSG_String &Value, const CSG_String &Proj4);
 
-	bool							_Set_Dictionary				(CSG_Table      &Dictionary, int Direction);
-	bool							_Set_Dictionary				(CSG_Translator &Dictionary, int Direction);
+	bool							_Set_Dictionary				(void);
+	bool							_Set_Dictionary				(CSG_Table &Dictionary, int Direction);
 
 };
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT CSG_Projections &	SG_Get_Projections	(void);
+SAGA_API_DLL_EXPORT CSG_Projections &	SG_Get_Projections		(void);
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT bool		SG_Get_Projected				(class CSG_Shapes *pSource, class CSG_Shapes *pTarget, const CSG_Projection &Target);
+SAGA_API_DLL_EXPORT bool				SG_Get_Projected		(class CSG_Shapes *pSource, class CSG_Shapes *pTarget, const CSG_Projection &Target);
 
-SAGA_API_DLL_EXPORT bool		SG_Get_Projected				(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Point &Point    );
-SAGA_API_DLL_EXPORT bool		SG_Get_Projected				(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Rect  &Rectangle);
+SAGA_API_DLL_EXPORT bool				SG_Get_Projected		(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Point &Point    );
+SAGA_API_DLL_EXPORT bool				SG_Get_Projected		(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Rect  &Rectangle);
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT bool		SG_Grid_Get_Geographic_Coordinates		(CSG_Grid *pGrid, CSG_Grid *pLon, CSG_Grid *pLat);
+SAGA_API_DLL_EXPORT bool				SG_Grid_Get_Geographic_Coordinates	(CSG_Grid *pGrid, CSG_Grid *pLon, CSG_Grid *pLat);
 
 
 ///////////////////////////////////////////////////////////
